@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from robocorp_ls_core.protocols import check_implements
 from robocorp_ls_core.robotframework_log import get_logger
@@ -6,6 +6,7 @@ from robotframework_ls.impl.protocols import (
     ICompletionContext,
     IKeywordFound,
     IKeywordCollector,
+    ILibraryDoc,
 )
 
 
@@ -118,6 +119,14 @@ class _Collector(object):
 
         self.completion_items.append(item)
 
+    def on_resolved_library(
+        self,
+        completion_context: ICompletionContext,
+        library_node,
+        library_doc: ILibraryDoc,
+    ):
+        pass
+
     def on_unresolved_library(
         self,
         completion_context: ICompletionContext,
@@ -126,6 +135,7 @@ class _Collector(object):
         end_lineno: int,
         col_offset: int,
         end_col_offset: int,
+        error_msg: Optional[str],
     ):
         pass
 
