@@ -22,7 +22,8 @@ from robocorp_ls_core.constants import NULL
 from robocorp_ls_core.protocols import TypedDict
 from collections import namedtuple
 import enum
-from robocorp_ls_core.lsp import SymbolKind, LocationTypedDict
+from robocorp_ls_core.lsp import SymbolKind, LocationTypedDict, RangeTypedDict
+import typing
 
 if sys.version_info[:2] < (3, 8):
 
@@ -38,7 +39,13 @@ Y = TypeVar("Y", covariant=True)
 
 
 class INode(Protocol):
-    pass
+    lineno: int
+    end_lineno: int
+    col_offset: int
+    end_col_offset: int
+
+    def get_token(self, name: str) -> Any:
+        pass
 
 
 class ILibraryImportNode(INode, Protocol):
@@ -96,20 +103,44 @@ class IKeywordArg(Protocol):
     def is_star_arg(self) -> bool:
         pass
 
+    def is_arg_type_set(self) -> bool:
+        pass
+
     @property
     def arg_type(self) -> Optional[str]:
         pass
 
+    def is_default_value_set(self) -> bool:
+        pass
+
     @property
     def default_value(self) -> Optional[str]:
         pass
 
 
+if typing.TYPE_CHECKING:
+    from robot.api import Token
+
+    IRobotToken = Token
+
+
+else:
+    # We don't want to import robot in this case (just do it when type-checking).
+    class IRobotToken(Protocol):
+        pass
+
+
 class ILibraryDoc(Protocol):
     filename: str
     name: str
     source: str
     symbols_cache: Optional["ISymbolsCache"]
+    inits: list
+
+
+class ILibraryDocOrError(Protocol):
+    library_doc: Optional[ILibraryDoc]
+    error: Optional[str]
 
 
 class IRobotDocument(IDocument, Protocol):
@@ -190,6 +221,10 @@ class IKeywordFound(Protocol):
     def docs(self) -> str:
         pass
 
+    @property
+    def docs_without_signature(self) -> str:
+        pass
+
     @property
     def docs_format(self) -> str:
         pass
@@ -270,6 +305,14 @@ class IKeywordCollector(Protocol):
         :param IKeywordFound keyword_found:
         """
 
+    def on_resolved_library(
+        self,
+        completion_context: "ICompletionContext",
+        library_node: Optional[INode],
+        library_doc: "ILibraryDoc",
+    ):
+        pass
+
     def on_unresolved_library(
         self,
         completion_context: "ICompletionContext",
@@ -278,6 +321,7 @@ class IKeywordCollector(Protocol):
         end_lineno: int,
         col_offset: int,
         end_col_offset: int,
+        error_msg: Optional[str],
     ):
         pass
 
@@ -521,3 +565,8 @@ class IVariablesCollector(Protocol):
 
     def on_variable(self, variable_found: IVariableFound):
         pass
+
+
+class EvaluatableExpressionTypedDict(TypedDict):
+    range: RangeTypedDict
+    expression: Optional[str]
