@@ -20,7 +20,7 @@ https://github.com/microsoft/language-server-protocol/tree/gh-pages/_specificati
 https://microsoft.github.io/language-server-protocol/specification
 """
 from __future__ import annotations
-from typing import List, Union, Optional, Any
+from typing import List, Union, Optional, Any, Tuple
 import typing
 
 from robocorp_ls_core.protocols import IEndPoint, IFuture, TypedDict
@@ -56,6 +56,10 @@ class CompletionItemKind(object):
     Issue = 26
 
 
+class CompletionItemTag(object):
+    Deprecated = 1
+
+
 class MarkupKind(object):
     PlainText = "plaintext"
     Markdown = "markdown"
@@ -74,6 +78,11 @@ class DiagnosticSeverity(object):
     Hint = 4
 
 
+class DiagnosticTag(object):
+    Unnecessary = 1
+    Deprecated = 2
+
+
 class InsertTextFormat(object):
     PlainText = 1
     Snippet = 2
@@ -252,6 +261,22 @@ class SignatureHelp(_Base):
         self.activeSignature = active_signature
         self.activeParameter = active_parameter
 
+        # This isn't part of the spec (just used to internally manipulate more information).
+        self.name = ""
+        self.node = None
+
+    def to_dict(self):
+        new_dict = {}
+        for key in ["signatures", "activeSignature", "activeParameter"]:
+            value = self[key]
+            if hasattr(value, "to_dict"):
+                value = value.to_dict()
+            if value.__class__ in (list, tuple):
+                value = [v.to_dict() if hasattr(v, "to_dict") else v for v in value]
+            if value is not None:
+                new_dict[key] = value
+        return new_dict
+
 
 class Position(_Base):
     def __init__(self, line=0, character=0):
@@ -739,18 +764,34 @@ class LSPMessages(object):
 
 class Error(object):
 
-    __slots__ = "msg start end".split(" ")
+    __slots__ = "msg start end severity tags".split(" ")
 
-    def __init__(self, msg, start, end):
+    def __init__(
+        self,
+        msg: str,
+        start: Tuple[int, int],
+        end: Tuple[int, int],
+        severity: int = DiagnosticSeverity.Error,
+    ):
         """
         Note: `start` and `end` are tuples with (line, col).
         """
         self.msg = msg
         self.start = start
         self.end = end
+        self.severity = severity
 
     def to_dict(self):
-        return dict((name, getattr(self, name)) for name in self.__slots__)
+        ret = {
+            "msg": self.msg,
+            "start": self.start,
+            "end": self.end,
+            "severity": self.severity,
+        }
+        tags = getattr(self, "tags", None)
+        if tags:
+            ret["tags"] = tags
+        return ret
 
     def __repr__(self):
         import json
@@ -760,12 +801,16 @@ class Error(object):
     __str__ = __repr__
 
     def to_lsp_diagnostic(self):
-        return {
+        tags = getattr(self, "tags", None)
+        ret = {
             "range": {
                 "start": {"line": self.start[0], "character": self.start[1]},
                 "end": {"line": self.end[0], "character": self.end[1]},
             },
-            "severity": DiagnosticSeverity.Error,
+            "severity": self.severity,
             "source": "robotframework",
             "message": self.msg,
         }
+        if tags:
+            ret["tags"] = tags
+        return ret
